pub struct Message {
pub role: MessageRole,
pub content: Vec<ContentBlock>,
}Expand description
A single message in a conversation, containing one or more content blocks.
Fields
role: MessageRoleThe role of the message sender.
content: Vec<ContentBlock>The content blocks that make up this message.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn assistant(text: impl Into<String>) -> Self
pub fn assistant(text: impl Into<String>) -> Self
Create an assistant message with a single text block.
Sourcepub fn system(text: impl Into<String>) -> Self
pub fn system(text: impl Into<String>) -> Self
Create a system message with a single text block.
Sourcepub fn text(&self) -> String
pub fn text(&self) -> String
Extract the concatenated text from all ContentBlock::Text blocks.