pub struct MultimodalInput {
pub blocks: Vec<MultimodalBlock>,
}Expand description
A heterogeneous input to a MultimodalEmbeddingModel.
Each input produces one embedding spanning all of its blocks. Multiple
inputs are batched together by passing a Vec<MultimodalInput>.
Fields
blocks: Vec<MultimodalBlock>Ordered sequence of content blocks that share a single embedding.